@@ -16,11 +16,11 @@ JSON::Any - Wrapper Class for the various JSON classes.
 
 =head1 VERSION
 
-Version 1.17
+Version 1.18
 
 =cut
 
-our $VERSION = '1.17';
+our $VERSION = '1.19';
 
 our $UTF8;
 
@@ -181,9 +181,6 @@ BEGIN {
               }
         },
     );
-
-    # JSON::PC claims it has the same API as JSON
-    $conf{json_pc} = $conf{json};
 }
 
 sub _make_key {
@@ -204,7 +201,7 @@ sub import {
 
     @order = split /\s/, $ENV{JSON_ANY_ORDER}
       if !@order and $ENV{JSON_ANY_ORDER};
-    @order = qw(XS JSON DWIW Syck) unless @order;
+    @order = qw(XS JSON DWIW) unless @order;
 
     foreach my $testmod (@order) {
         $testmod = "JSON::$testmod" unless $testmod eq "JSON";
@@ -262,13 +259,12 @@ for them in this order:
 	JSON::XS 
 	JSON 
 	JSON::DWIW 
-	JSON::Syck
 
 And loading the first one it finds.
 
 You may change the order by specifying it on the C<use JSON::Any> line:
 
-	use JSON::Any qw(DWIW Syck XS JSON);
+	use JSON::Any qw(DWIW XS JSON);
 
 Specifying an order that is missing one of the modules will prevent that module from being used:
 
@@ -277,6 +273,17 @@ Specifying an order that is missing one of the modules will prevent that module
 This will check in that order, and will never attempt to load JSON::Syck. This can also be set via
 the $ENV{JSON_ANY_ORDER} environment variable.
 
+JSON::Syck has been deprecated by it's author, but in the attempt to still stay relevant as a "Compat Layer" 
+JSON::Any still supports it. This support however has been made optional, and disabled by default. If you would like
+to use JSON::Any with version 1.19 and above you'll need to explicitly add it to the import list.
+
+    use JSON::Any qw(Syck XS JSON); 
+    
+or 
+
+    $ENV{JSON_ANY_ORDER} = 'Syck XS JSON';
+
+
 WARNING: If you call JSON::Any with an empty list
 
     use JSON::Any ();
@@ -508,7 +515,8 @@ underlying JSON module.
 =head1 AUTHOR
 
 Chris Thompson, C<< <cthom at cpan.org> >>
-Chris Prather, C<< <perigrin at cpan.org> >>
+Chris Prather, C<< <chris at prather.org> >>
+Robin Berjon, C<< robin at berjon.com >>
 
 =head1 BUGS
 
@@ -533,7 +541,7 @@ San Dimas High School Football Rules!
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007 Chris Thompson, some rights reserved.
+Copyright 2007-2009 Chris Thompson, some rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
